@@ -93,7 +93,7 @@
   (set-statusbar-message (get-stock-no-string)))
 
 (define (get-stock-no-string)
-  (string-append (_"Stock left:  ")
+  (string-append (_"Stock left:") " "
 		 (number->string (length (get-cards 0)))))
 
 (define (button-pressed slot-id card-list)
@@ -106,7 +106,7 @@
 	     (= slot-id 1))
 	 #f)
 	((= slot-id 22)
-	 (and (empty-slot? 28)
+	 (and (empty-slot? 29)
 	      (empty-slot? 28)))
 	((= slot-id 21)
 	 (and (empty-slot? 27)
